@@ -200,12 +200,12 @@ def vt_probability_fho(g: float, T: float, mass: float, beta: float, ve_before:
 
     eps = (cosh((1.0 + phi) * omega / (beta * vel))
            / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
-    eps *= 4.0 * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h * constants.pi * s)
+    eps *= 4.0 * (constants.pi ** 2) * svt(delta) * omega * mass / ((beta ** 2) * constants.h)
     return ns * (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
 
 
 def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int,
-                       delta: int, depth: float, svt: float=0.33) -> float:
+                       delta: int, depth: float, this_svt: float=0.33) -> float:
     """Returns the velocity-dependent part of the probability of a VT transition using
     the FHO (Forced harmonic oscillator) model **M(i) + P -> M(i + delta) + P**
 
@@ -248,7 +248,7 @@ def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before:
 
         eps = (cosh((1.0 + phi) * omega / (beta * vel))
                / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
+        eps *= 4.0 * this_svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return eps * exp(-(i + 1) * eps)
     elif delta == -1:
         omega = (ve_before - ve_after) / constants.hbar
@@ -256,7 +256,7 @@ def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before:
 
         eps = (cosh((1.0 + phi) * omega / (beta * vel))
                / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
+        eps *= 4.0 * this_svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return eps * exp(-i * eps)
     elif delta > 0:
         s = delta * 1.0
@@ -266,7 +266,7 @@ def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before:
         phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
         eps = (cosh((1.0 + phi) * omega / (beta * vel))
                / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
+        eps *= 4.0 * this_svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
     else:
         s = -delta * 1.0
@@ -276,7 +276,7 @@ def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before:
         phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
         eps = (cosh((1.0 + phi) * omega / (beta * vel))
                / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
-        eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
+        eps *= 4.0 * this_svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
         return (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
 
 
@@ -325,8 +325,6 @@ def vv_probability_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         ns1 = fact_div_fact(i + i_delta, i)
         ns2 = fact_div_fact(k, k - i_delta)
 
-    svv = ((factorial(s + 3)) * ((1. + 1. / (2. ** (s - 1))) ** 4)) / ((2. ** (s + 8)) * (s + 1) * (s + 1) * 6)
-
     vel = vel_avg_vv(g * (2.0 * constants.k * T / mass) ** 0.5, ve_before1, ve_after1, ve_before2, ve_after2, mass)
 
     if vel < 0:
@@ -340,15 +338,15 @@ def vv_probability_fho(g: float, T: float, mass: float, beta: float, ve_before1:
 
     xi = 2 * abs(omega1 - omega2) / (beta * vel)
     if xi < 1.0 ** (-4):
-        rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
+        rhoxi = 0.25 * svv(i_delta) * ((beta * vel) ** 2) / (omega1 * omega2)
     else:
-        rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
+        rhoxi = svv(i_delta) * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
     return (rhoxi ** s) * ns1 * ns2 * exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
 
 
 def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
-                       ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int, svv: float=0.04) -> float:
+                       ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int, this_svv: float=0.04) -> float:
     """Returns the velocity-dependent part of the probability of a VV transition using the FHO
     (Forced harmonic oscillator) model **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
 
@@ -394,9 +392,9 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
 
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)  # 0.0078125 is 0.03125 * 0.25, svv=0.03125
+            rhoxi = 0.25 * this_svv * ((beta * vel) ** 2) / (omega1 * omega2)  # 0.0078125 is 0.03125 * 0.25, svv=0.03125
         else:
-            rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
+            rhoxi = this_svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
         return rhoxi * exp(-((i + 1) * k) * rhoxi)
     elif i_delta == -1:
@@ -405,9 +403,9 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)  # 0.0078125 is 0.03125 * 0.25, svv=0.03125
+            rhoxi = 0.25 * this_svv * ((beta * vel) ** 2) / (omega1 * omega2)  # 0.0078125 is 0.03125 * 0.25, svv=0.03125
         else:
-            rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
+            rhoxi = this_svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
         return rhoxi * exp(-(i * (k + 1)) * rhoxi)
     elif i_delta > 0:
@@ -417,9 +415,9 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * this_svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
+            rhoxi = this_svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
         return (rhoxi ** s) * exp(-2.0 * ((fact_div_fact(i, i + i_delta) * fact_div_fact(k - i_delta, k)) ** (1.0 / s))
                             * rhoxi / (s + 1))
@@ -430,9 +428,9 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * this_svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
+            rhoxi = this_svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
         return (rhoxi ** s) * exp(-2.0 * ((fact_div_fact(i + i_delta, i) * fact_div_fact(k, k - i_delta)) ** (1.0 / s))
                             * rhoxi / (s + 1))
\ No newline at end of file
